@@ -1,4 +1,6 @@
-//@line 37 "/home/cltbld/build/maemo-1.9.2-nightly/mozilla-1.9.2/toolkit/mozapps/extensions/content/blocklist.js"
+//@line 37 "/home/cltbld/build/mozilla-2.1-mob-maemo5-gtk/mozilla-2.1/toolkit/mozapps/extensions/content/blocklist.js"
+
+Components.utils.import("resource://gre/modules/Services.jsm");
 
 var gArgs;
 
@@ -7,6 +9,15 @@ function init() {
   var hasSoftBlocks = false;
   gArgs = window.arguments[0].wrappedJSObject;
 
+  // NOTE: We use strings from the "updates.properties" bundleset to change the
+  // text on the "Cancel" button to "Restart Later". (bug 523784)
+  let bundle = Services.strings.
+              createBundle("chrome://mozapps/locale/update/updates.properties");
+  let cancelButton = document.documentElement.getButton("cancel");
+  cancelButton.setAttribute("label", bundle.GetStringFromName("restartLaterButton"));
+  cancelButton.setAttribute("accesskey",
+                            bundle.GetStringFromName("restartLaterButton.accesskey"));
+
   var richlist = document.getElementById("addonList");
   var list = gArgs.list;
   list.sort(function(a, b) { return String.localeCompare(a.name, b.name); });
@@ -40,8 +51,8 @@ function init() {
   link.setAttribute("href", url);
 }
 
-function accept() {
-  gArgs.restart = true;
+function finish(shouldRestartNow) {
+  gArgs.restart = shouldRestartNow;
   var list = gArgs.list;
   var items = document.getElementById("addonList").childNodes;
   for (let i = 0; i < list.length; i++) {
